@@ -9,6 +9,7 @@ from django.utils.text import capfirst
 from django.utils.translation import ugettext_lazy as _
 
 from .codecs import decode_csv_to_list, encode_list_to_csv
+from .validators import MaxChoicesValidator, MaxLengthValidator
 import select_multiple_field.forms as forms
 
 
@@ -34,15 +35,21 @@ class SelectMultipleField(six.with_metaclass(models.SubfieldBase,
 
     def __init__(self, *args, **kwargs):
         """
-        SelectMultipleField rejects items with no answer
+        SelectMultipleField rejects items with no answer by default
 
         By default responses are required, so 'blank' is False
         """
         if 'max_choices' in kwargs:
             self.max_choices = kwargs.pop('max_choices')
 
+        if 'include_blank' in kwargs:
+            self.include_blank = kwargs.pop('include_blank')
+
         super(SelectMultipleField, self).__init__(*args, **kwargs)
-        self.validators.append(validators.MaxLengthValidator(self.max_length))
+
+        self.validators.append(MaxLengthValidator(self.max_length))
+        if hasattr(self, 'max_choices'):
+            self.validators.append(MaxChoicesValidator(self.max_choices))
 
     def __str__(self):
         return "%s" % force_text(self.description)
@@ -98,9 +105,18 @@ class SelectMultipleField(six.with_metaclass(models.SubfieldBase,
         Choices from model without initial blank choices
 
         ie Stop widget from producing <option value="">---------</option>
+
+        If ModelField.include_blank is set then ignore any overrides sent via
+        kwargs
         """
+        include_blank = False
+        if hasattr(self, 'include_blank'):
+            include_blank = self.include_blank
+            if 'include_blank' in kwargs:
+                kwargs.pop('include_blank')
+
         field_options = {
-            'include_blank': False
+            'include_blank': include_blank
         }
         field_options.update(kwargs)
         return super(SelectMultipleField, self).get_choices(**field_options)
@@ -118,7 +134,9 @@ class SelectMultipleField(six.with_metaclass(models.SubfieldBase,
             if isinstance(value, (list, tuple)):
                 bad_values = []
                 for opt in value:
-                    if opt not in self.get_choices_keys():
+                    if self.blank and opt in validators.EMPTY_VALUES:
+                        pass
+                    elif opt not in self.get_choices_keys():
                         bad_values.append(opt)
                 if len(bad_values) == 0:
                     return
@@ -172,6 +190,9 @@ class SelectMultipleField(six.with_metaclass(models.SubfieldBase,
         """
         Checks that value is in choices
         """
+        if self.blank and value in validators.EMPTY_VALUES:
+            return True
+
         flat_choices = self.get_choices_keys()
         return value in flat_choices
 
