@@ -20,7 +20,7 @@ class ChickenWings(models.Model):
     MILD = 'M'
     CAJUN = 'c'
     JERK = 'j'
-    HONEY_GARLIC = 'h'
+    HONEY_GARLIC = 'g'
     HONEY_BBQ = 'H'
     THAI = 't'
     BACON = 'b'
@@ -41,6 +41,8 @@ class ChickenWings(models.Model):
             (BOURBON, _('Bourbon whiskey barbeque')))),
     )
     flavour = SelectMultipleField(
+        blank=True,
+        include_blank=False,
         max_length=5,
         max_choices=2,
         choices=FLAVOUR_CHOICES
@@ -51,3 +53,23 @@ class ChickenWings(models.Model):
 
     def get_absolute_url(self):
         return reverse('ftw:detail', args=[self.pk])
+
+
+def show_flavour(flavour):
+    """
+    Decode flavour to full name
+
+    This supports both plain choices and optgroup choices
+    """
+    decoder = dict()
+    for c in ChickenWings.FLAVOUR_CHOICES:
+        if isinstance(c[1], (tuple, list)):
+            for k, v in c[1]:
+                decoder[k] = v
+        else:
+            decoder[c[0]] = c[1]
+
+    if flavour in decoder:
+        return force_text(decoder[flavour])
+    else:
+        return force_text('')
