@@ -22,3 +22,24 @@ class ChickenWingsCreateView(CreateView):
     fields = ['flavour']
     success_url = reverse_lazy('ftw:created')
     context_object_name = 'wings'
+
+
+class ChickenWingsDetailView(DetailView):
+
+    model = ChickenWings
+
+
+class ChickenWingsUpdateView(UpdateView):
+
+    model = ChickenWings
+    fields = ['flavour']
+    success_url = reverse_lazy('ftw:updated')
+
+
+class ChickenWingsDeleteView(DeleteView):
+
+    model = ChickenWings
+    success_url = reverse_lazy('ftw:deleted')
+
+    def get_success_url(self):
+        return force_text(self.success_url)
