@@ -4,6 +4,7 @@ from __future__ import unicode_literals
 import collections
 import string
 
+from django.core import validators
 from django.core.exceptions import ValidationError
 from django.db.models.fields import BLANK_CHOICE_DASH, CharField, Field
 from django.test import SimpleTestCase
@@ -53,6 +54,12 @@ class SelectMultipleFieldTestCase(SimpleTestCase):
             item = SelectMultipleField(max_choices=max_choices)
             self.assertEqual(item.max_choices, max_choices)
 
+    def test_instantiation_include_blank(self):
+        item = SelectMultipleField(include_blank=False)
+        self.assertFalse(item.include_blank)
+        item = SelectMultipleField(include_blank=True)
+        self.assertTrue(item.include_blank)
+
     def test_get_internal_type(self):
         item = SelectMultipleField()
         charfield = CharField()
@@ -160,6 +167,29 @@ class SelectMultipleFieldTestCase(SimpleTestCase):
         self.assertIsInstance(choices[0], tuple)
         self.assertIn(BLANK_CHOICE_DASH[0], choices)
 
+    def test_get_choices_include_blank(self):
+        """
+        Explicit include_blank value is honored, ignoring passed parameters
+        """
+        item = SelectMultipleField(choices=self.choices, include_blank=True)
+        choices = item.get_choices()
+        self.assertIsInstance(choices, list)
+        self.assertIsInstance(choices[0], tuple)
+        self.assertIn(BLANK_CHOICE_DASH[0], choices)
+        choices = item.get_choices(include_blank=False)
+        self.assertIsInstance(choices, list)
+        self.assertIsInstance(choices[0], tuple)
+        self.assertIn(BLANK_CHOICE_DASH[0], choices)
+        item = SelectMultipleField(choices=self.choices, include_blank=False)
+        choices = item.get_choices()
+        self.assertIsInstance(choices, list)
+        self.assertIsInstance(choices[0], tuple)
+        self.assertNotIn(BLANK_CHOICE_DASH[0], choices)
+        choices = item.get_choices(include_blank=True)
+        self.assertIsInstance(choices, list)
+        self.assertIsInstance(choices[0], tuple)
+        self.assertNotIn(BLANK_CHOICE_DASH[0], choices)
+
     def test_validate_valid_choices(self):
         for choices in self.test_choices:
             item = SelectMultipleField(choices=choices[0])
@@ -218,6 +248,14 @@ class SelectMultipleFieldTestCase(SimpleTestCase):
             SelectMultipleField.default_error_messages['null']
         )
 
+    def test_validate_blank(self):
+        item = SelectMultipleField(choices=self.choices)
+        item.editable = True
+        item.blank = True
+        value = ['']
+        instance = "Fake Unused Instance"
+        self.assertIs(item.validate(value, instance), None)
+
     def test_validate_not_blank(self):
         item = SelectMultipleField(choices=self.choices)
         item.editable = True
@@ -249,15 +287,22 @@ class SelectMultipleFieldTestCase(SimpleTestCase):
                 % {'value': value[0]})
         )
 
-    def test_validate_choice_true(self):
+    def test_validate_option_choice_true(self):
         item = SelectMultipleField(choices=self.choices)
         for n in range(len(self.choices_list) - 1):
             self.assertTrue(item.validate_option(self.choices_list[n]))
 
-    def test_validate_choice_false(self):
+    def test_validate_option_choice_false(self):
         item = SelectMultipleField(choices=self.choices)
         self.assertFalse(item.validate_option("InvalidChoice"))
 
+    def test_validate_option_choice_blank_values(self):
+        item = SelectMultipleField(choices=self.choices)
+        item.blank = True
+        self.assertTrue(item.blank)
+        for value in validators.EMPTY_VALUES:
+            self.assertTrue(item.validate_option(value))
+
     def test_get_choices_keys(self):
         item = SelectMultipleField(choices=self.choices)
         self.assertEqual(item.get_choices_keys(), self.choices_list)
